@@ -1,7 +1,7 @@
 import requests
 import json
 import time
-from Rrequests import Request
+from .Rrequests import Request
 
 
 class Rusty:
@@ -18,7 +18,7 @@ class Rusty:
 
     def pkginfo():
         NAME = 'rustylib'
-        VERSION = '1.5.8'
+        VERSION = '1.5.9'
         cache = []
         web = Request("https://raw.githubusercontent.com/ZeyaTsu/rustylib/main/Rpkg_info.json")
         res = web.send()
